import requests


class API:
    def __init__(self, token):
        self.api_key = token
        self.base_url = "https://api.logicarbor.com/v3.0"

    def checkUser(self, userId):
        url = f"{self.base_url}/?mode=check&user_id={userId}&key={self.api_key}"
        response = requests.get(url)
        return response.text

    def editUser(self, userId, userName="", endDate=""):
        url = f"{self.base_url}/?mode=edit&user_id={userId}&key={self.api_key}&user_name={userName}&end_date={endDate}"
        response = requests.get(url)
        return response.text

    def addUser(self, userName, endDate=""):
        url = f"{self.base_url}/?mode=add&key={self.api_key}&user_name={userName}&end_date={endDate}"
        response = requests.get(url)
        return response.text

    def enableUser(self, userId):
        url = f"{self.base_url}/?mode=enable&key={self.api_key}&user_id={userId}"
        response = requests.get(url)
        return response.text

    def disableUser(self, userId):
        url = f"{self.base_url}/?mode=disable&key={self.api_key}&user_id={userId}"
        response = requests.get(url)
        return response.text

    def deleteUser(self, userId):
        url = f"{self.base_url}/?mode=delete&key={self.api_key}&user_id={userId}"
        response = requests.get(url)
        return response.text



from setuptools import setup

setup(
    name='logicarbor',
    version='0.1.0',
    description='Python client for Logicarbor API',
    author='logicarbor dev team',
    author_email='admin@logicarbor.com',
    url='https://api.logicarbor.com/v3.0/documentation.html',
    packages=['logicarbor'],
    install_requires=['requests'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
